@@ -136,9 +136,10 @@ class DownloadSession:
                                            raise_for_status=True, proxy=proxy) as resp:
             content_type = resp.headers.get('Content-Type')
             if 'text' in content_type.lower() or 'html' in content_type.lower():
-                logger.debug("Server for %s is either down or the file no longer exists", str(url))
+                logger.debug("Server for %s is experiencing issues, or you are being ratelimited", str(url))
+                logger.debug("Content received: " + content_type.lower())
                 await File_Lock.remove_lock(original_filename)
-                raise FailureException(code=resp.status, message="Unexpectedly got text as response")
+                raise FailureException(code=resp.status, message="Unexpectedly got text as response", rescrape=True)
 
             total = int(resp.headers.get('Content-Length', str(0))) + resume_point
             (folder / title).mkdir(parents=True, exist_ok=True)
