@@ -11,7 +11,8 @@ import aiohttp.client_exceptions
 from tqdm import tqdm
 from yarl import URL
 
-from ..base_functions.base_functions import FILE_FORMATS, MAX_FILENAME_LENGTH, log, logger, sanitize, FailureException
+from ..base_functions.base_functions import FILE_FORMATS, MAX_FILENAME_LENGTH, log, logger, sanitize, FailureException, \
+    is_forum
 from ..base_functions.sql_helper import SQLHelper
 from ..base_functions.data_classes import AlbumItem, CascadeItem, FileLock, AuthData, SkipData
 from ..client.client import Client, DownloadSession
@@ -119,13 +120,6 @@ class Downloader:
             db_path.pop(1)
             db_path = '/' + '/'.join(db_path)
 
-        # return if completed already
-        if await self.SQL_helper.sql_check_existing(db_path):
-            if url.parts[-1] in self.current_attempt.keys():
-                self.current_attempt.pop(url.parts[-1])
-            logger.debug(msg=f"{db_path} found in DB: Skipping {filename}")
-            return
-
         try:
             async with self._semaphore:
                 # Make suffix always lower case
@@ -145,6 +139,7 @@ class Downloader:
                         if complete_file.stat().st_size == total_size:
                             await self.SQL_helper.sql_insert_file(db_path, complete_file.name, 1)
                             logger.debug("\nFile already exists and matches expected size: " + str(complete_file))
+                            await self.File_Lock.remove_lock(original_filename)
                             return
 
                     download_name = await self.SQL_helper.get_download_filename(db_path)
@@ -204,6 +199,8 @@ class Downloader:
                     pass
                 else:
                     return
+            if await is_forum(referral):
+                return
             raise FailureException(code=e.code, message=e.message, rescrape=e.rescrape)
 
         except (aiohttp.client_exceptions.ClientPayloadError, aiohttp.client_exceptions.ClientOSError,
@@ -324,6 +321,21 @@ class Downloader:
         url, referral = url_tuple
 
         logger.debug("Working on " + str(url))
+        db_path = url.path
+
+        if 'anonfiles' in url.host:
+            db_path = db_path.split('/')
+            db_path.pop(0)
+            db_path.pop(1)
+            db_path = '/' + '/'.join(db_path)
+
+        # return if completed already
+        if await self.SQL_helper.sql_check_existing(db_path):
+            if url.parts[-1] in self.current_attempt.keys():
+                self.current_attempt.pop(url.parts[-1])
+            logger.debug(msg=f"{db_path} found in DB: Skipping {db_path}")
+            return
+
         try:
             filename = await self.get_filename(url, referral, session)
             if await self.check_exclude(filename):
