@@ -9,12 +9,13 @@ from ..client.client import Session
 
 
 class CyberfileCrawler:
-    def __init__(self):
+    def __init__(self, quiet: bool):
+        self.quiet = quiet
         self.load_files = URL('https://cyberfile.is/account/ajax/load_files')
         self.file_details = URL('https://cyberfile.is/account/ajax/file_details')
 
     async def fetch(self, session: Session, url: URL):
-        await log("Starting scrape of " + str(url))
+        await log("Starting scrape of " + str(url), quiet=self.quiet)
         domain_obj = DomainItem("cyberfile.is", {})
         download_links = []
         if 'folder' in url.parts:
@@ -32,7 +33,7 @@ class CyberfileCrawler:
                 download_links = await self.get_download_links(session, url, [("Loose Cyberfile Files", contentId)])
         for title, download_link in download_links:
             await domain_obj.add_to_album(title, download_link, url)
-        await log("Finished scrape of " + str(url))
+        await log("Finished scrape of " + str(url), quiet=self.quiet)
         return domain_obj
 
     async def folder_nodeId(self, session: Session, url: URL):
@@ -45,7 +46,7 @@ class CyberfileCrawler:
             return nodeId
 
         except Exception as e:
-            await log("Error scraping " + str(url))
+            await log("Error scraping " + str(url), quiet=self.quiet)
             logger.debug(e)
             return 0
 
@@ -65,7 +66,7 @@ class CyberfileCrawler:
             return None
 
         except Exception as e:
-            await log("Error scraping " + str(url))
+            await log("Error scraping " + str(url), quiet=self.quiet)
             logger.debug(e)
             return 0
 
@@ -104,7 +105,7 @@ class CyberfileCrawler:
             return nodes, contents
 
         except Exception as e:
-            await log("Error scraping " + str(url))
+            await log("Error scraping " + str(url), quiet=self.quiet)
             logger.debug(e)
             return []
 
@@ -137,7 +138,7 @@ class CyberfileCrawler:
             return contents
 
         except Exception as e:
-            await log("Error scraping " + str(url))
+            await log("Error scraping " + str(url), quiet=self.quiet)
             logger.debug(e)
             return []
 
@@ -172,7 +173,7 @@ class CyberfileCrawler:
             return contents
 
         except Exception as e:
-            await log("Error scraping " + str(url))
+            await log("Error scraping " + str(url), quiet=self.quiet)
             logger.debug(e)
             return []
 
@@ -197,6 +198,6 @@ class CyberfileCrawler:
             return download_links
 
         except Exception as e:
-            await log("Error scraping " + str(url))
+            await log("Error scraping " + str(url), quiet=self.quiet)
             logger.debug(e)
             return []
